ninjadog.ext package — ninjadog 0.3.9 documentation

# ninjadog.ext package

## Submodules

## ninjadog.ext.pyramid module

class `ninjadog.ext.pyramid.` `PugRendererFactory`

  Bases: `object`

  Renderer factory conforms to IRendererFactory interface.

  `environment` = None

class `ninjadog.ext.pyramid.` `PugTemplateRenderer`(template_loader)

  Bases: `pyramid_jinja2.Jinja2TemplateRenderer`

  Renders templates that have both pug and jinja2 syntax.

  Conforms to IRenderer interface.

`ninjadog.ext.pyramid.` `add_pug_renderer`(config, name, settings_prefix=’jinja2.’, package=None)

  This function is added as a method of a Configurator, and should not be called directly. Instead it should be called like so after `pyramid_jinja2` has been passed to `config.include`: .. code-block:: python

  > config.add_jinja2_renderer(‘.html’, settings_prefix=’jinja2.’)

  It will register a new renderer, loaded from settings at the specified `settings_prefix` prefix. This renderer will be active for files using the specified extension `name`.

`ninjadog.ext.pyramid.` `includeme`(config)

## Module contents